@@ -8,6 +8,8 @@ from decimal import Decimal
 from django.conf import settings
 from coop.models import URIModel
 from coop.utils.fields import MultiSelectField
+import rdflib
+from django.contrib.contenttypes import generic
 
 if "coop_geo" in settings.INSTALLED_APPS:
     from coop_geo.models import Area, Location
@@ -17,18 +19,21 @@ class BaseProduct(URIModel):
     title = models.CharField(_('title'), blank=True, max_length=250)
     slug = exfields.AutoSlugField(populate_from='title', overwrite=True)
     description = models.TextField(_(u'description'), blank=True)
-    organization = models.ForeignKey('coop_local.Organization', blank=True, null=True, 
+    organization = models.ForeignKey('coop_local.Organization', blank=True, null=True,
                                         verbose_name='publisher', related_name='products')
-    organization_uri = models.CharField(_(u'publisher URI'), blank=True, max_length=200, editable=False)
+
+    remote_organization_uri = models.CharField(_(u'publisher URI'), blank=True, max_length=200, editable=False)
+    remote_organization_label = models.CharField(_('organization'), blank=True, max_length=250)
 
     def __unicode__(self):
-        return self.title
+        return self.title + u' (' + self.organization.__unicode__() + u')'
 
     class Meta:
         abstract = True
         ordering = ['-modified']
         verbose_name = _(u'Product')
         verbose_name_plural = _(u'Products')
+        app_label = 'coop_local'
 
 
 EWAY = Choices(
@@ -47,7 +52,7 @@ ETYPE = Choices(
 
 class BaseExchangeMethod(models.Model):  # this model will be initialized with a fixture
     label = models.CharField(_(u'label'), max_length=250)
-    uri = models.CharField(_(u'URI'), blank=True, max_length=250)  
+    uri = models.CharField(_(u'URI'), blank=True, max_length=250)
     etypes = MultiSelectField(_(u'applicable to'), max_length=250, null=True, blank=True, choices=ETYPE.CHOICES)
 
     def applications(self):
@@ -61,12 +66,14 @@ class BaseExchangeMethod(models.Model):  # this model will be initialized with a
         abstract = True
         verbose_name = _(u'Exchange method')
         verbose_name_plural = _(u'Exchange methods')
+        app_label = 'coop_local'
 
 
 class BaseExchange(URIModel):
     title = models.CharField(_('title'), max_length=250)
     description = models.TextField(_(u'description'), blank=True)
-    organization = models.ForeignKey('coop_local.Organization', blank=True, null=True, 
+
+    organization = models.ForeignKey('coop_local.Organization', blank=True, null=True,
                             verbose_name=_('publisher'), related_name='exchanges')
     person = models.ForeignKey('coop_local.Person', blank=True, null=True, verbose_name=_(u'person'))
 
@@ -77,24 +84,29 @@ class BaseExchange(URIModel):
     expiration = models.DateField(_(u'expiration'), blank=True, null=True)
     slug = exfields.AutoSlugField(populate_from='title', overwrite=True)
     products = models.ManyToManyField('coop_local.Product', verbose_name=_(u'linked products'))
-    person_uri = models.CharField(_(u'person URI'), blank=True, max_length=200, editable=False)
-    organization_uri = models.CharField(_(u'publisher URI'), blank=True, max_length=200, editable=False)
+
+    remote_person_uri = models.CharField(_(u'person URI'), blank=True, max_length=200, editable=False)
+    remote_person_label = models.CharField(_('person'), blank=True, max_length=250)
+
+    remote_organization_uri = models.CharField(_(u'organization URI'), blank=True, max_length=200, editable=False)
+    remote_organization_label = models.CharField(_('organization'), blank=True, max_length=250)
 
     methods = models.ManyToManyField('coop_local.ExchangeMethod', verbose_name=_(u'exchange methods'))
 
+    if "coop.agenda" in settings.INSTALLED_APPS:
+        dated = generic.GenericRelation('coop_local.Dated')
 
     # coop_geo must be loaded BEFORE coop_local
     if "coop_geo" in settings.INSTALLED_APPS:
 
-        location = models.ForeignKey(   Location, 
-                                        verbose_name=_(u'location'), 
+        location = models.ForeignKey(   Location,
+                                        verbose_name=_(u'location'),
                                         null=True, blank=True, related_name='exchange_location',
                                         help_text=_("choose a location among your registered locations."))
-        area = models.ForeignKey(Area, 
-                                 verbose_name=_(u'interest area'), 
+        area = models.ForeignKey(Area,
+                                 verbose_name=_(u'interest area'),
                                  null=True, blank=True, related_name='exchange_area',
                                  help_text=_("choose an area among your registered impact areas."))
- 
 
     def __unicode__(self):
         return unicode(self.title)
@@ -102,6 +114,9 @@ class BaseExchange(URIModel):
     def get_absolute_url(self):
         return reverse('exchange_detail', args=[self.id])
 
+    def label(self):
+        return self.title
+
     #TODO assign the record to the person editing it (form public) and provide an A-C choice in admin
 
     class Meta:
@@ -109,6 +124,19 @@ class BaseExchange(URIModel):
         ordering = ('-modified',)
         verbose_name = _(u'Exchange')
         verbose_name_plural = _(u'Exchanges')
+        app_label = 'coop_local'
+
+    # title field needs a special handling. checkDirectMap does not work
+    # because two rdf property use the coop_local_organization.title field
+    # Thus we have to decide which one to use
+    def updateField_title(self, dbfieldname, graph):
+            title = list(graph.objects(rdflib.term.URIRef(self.uri), settings.NS.rdfs.label))
+            if len(title) == 1:
+                self.title = title[0]
+                print "For id %s update the field %s" % (self.id, dbfieldname)
+            else:
+                print "    The field %s cannot be updated." % dbfieldname
+
 
 
 class BaseTransaction(models.Model):
@@ -129,6 +157,7 @@ class BaseTransaction(models.Model):
         abstract = True
         verbose_name = _(u'Transaction')
         verbose_name_plural = _(u'Transactions')
+        app_label = 'coop_local'
 
 
 # MODALITIES = Choices(
@@ -139,7 +168,7 @@ class BaseTransaction(models.Model):
 # UNITS = Choices(
 #     ('EURO',    1,  _(u'€')),
 #     ('SELH',    2,  _(u'Hours')),
-#     ('PEZ',     3,  _(u'PEZ')),    
+#     ('PEZ',     3,  _(u'PEZ')),
 # )
 
 
@@ -163,7 +192,7 @@ class BaseTransaction(models.Model):
 #         if not self.modality == 3:
 #             self.amount = Decimal(0.00)
 #             self.unit = None
-#         super(BasePaymentModality, self).save(*args, **kwargs) 
+#         super(BasePaymentModality, self).save(*args, **kwargs)
 
 #     class Meta:
 #         abstract = True
