@@ -8,8 +8,9 @@ from djaloha.widgets import AlohaInput
 class ArticleForm(CmsArticleForm):
     class Meta:
         model = get_article_class()
-        fields = ('title', 'content', 'logo')
+        fields = ('title', 'summary', 'content', 'logo')
         widgets = {
             'title': AlohaInput(text_color_plugin=False),
+            'summary': AlohaInput(text_color_plugin=False),
             'content': AlohaInput(text_color_plugin=False),
         }
\ No newline at end of file
